require 'test_helper'
require_relative "test_page.rb"
require_relative "test_refreshable.rb"

describe "Datarobot::AiApi::Dataset" do
  before do
    @key = "testingKey"
  end

  it "is sane" do
    Datarobot::AiApi::AI.new
    # if we make it to here, nothing has exploded
    assert true
  end

  describe "when authorized" do
    before do
      Datarobot::AiApi.configure!(api_key: @key)
      @klass = Datarobot::AiApi::Dataset
      @id = "5d4b20f37741a3052f171759"
    end

    it_behaves_like "a paginated resource"
    it_behaves_like "a refreshable resource"

    it "can list datasets", vcr: true do
      datasets = Datarobot::AiApi::Dataset.all
      assert datasets.is_a? Datarobot::AiApi::Page
      assert_equal datasets.length, 38
      assert_includes(datasets.map(&:name), "chords_part0000.csv")
    end

    it "can find datasets", vcr: true do
      dataset = Datarobot::AiApi::Dataset.find('5d4b20f37741a3052f171759')
      assert dataset.is_a? Datarobot::AiApi::Dataset
      assert_equal dataset.name, "chords_part0000.csv"
    end
    
    it "handles when the dataset ID is nil" do
      assert_raises Datarobot::AiApi::NotFoundError do
        ai = Datarobot::AiApi::Dataset.find(nil)
      end
    end

    it "can delete datasets", vcr: true do
      dataset = Datarobot::AiApi::Dataset.delete('5d41f1bbd8c81f05c9732a25')
      assert_nil dataset
    end

    it "can import a dataset from a file", vcr: true do
      dataset = Datarobot::AiApi::Dataset.create_from_file('./test/data/delete-me.csv')
      assert dataset.is_a? Datarobot::AiApi::Dataset
      assert_equal dataset.name, "delete-me.csv"
      assert dataset.id
    end

    it "can import a dataset from a url", vcr: true do
      dataset = Datarobot::AiApi::Dataset.create_from_url('https://projects.fivethirtyeight.com/congress-model-2018/house_national_forecast.csv')
      assert dataset.is_a? Datarobot::AiApi::Dataset
      assert_equal dataset.name, "house_national_forecast.csv"
      assert dataset.id
    end
  end
end
