require 'test_helper'
require_relative 'test_page.rb'
require_relative "test_refreshable.rb"

describe "Datarobot::AiApi::LearningSession" do
  before do
    @key = "testingKey"
  end

  it "is sane" do
    Datarobot::AiApi::LearningSession.new
    # if we make it to here, nothing has exploded
    assert true
  end

  describe "when authorized" do
    before do
      Datarobot::AiApi.configure!(api_key: @key)
      @klass = Datarobot::AiApi::LearningSession
      @id = '5d41e055d8c81f0587732a93'
    end

    it_behaves_like "a paginated resource"
    it_behaves_like "a refreshable resource"

    it "can list learning sessions", vcr: true do
      sessions = Datarobot::AiApi::LearningSession.all
      assert sessions.is_a? Datarobot::AiApi::Page
      assert_equal sessions.length, 19
    end

    it "can find learning sessions", vcr: true do
      session = Datarobot::AiApi::LearningSession.find('5d322f2c5c142b15d2f826e7')
      assert session.is_a? Datarobot::AiApi::LearningSession
      assert_equal session.name, "Learning class"
    end

    it "handles when the learning session ID is nil" do
      assert_raises Datarobot::AiApi::NotFoundError do
        ai = Datarobot::AiApi::LearningSession.find(nil)
      end
    end

    it "can create learning sessions", vcr: true do
      session = Datarobot::AiApi::LearningSession.create(dataset_id: '5d656bb042eabf201366f2d7', target: 'score1')
      assert session.is_a? Datarobot::AiApi::LearningSession
    end

    it "can delete learning sessions", vcr: true do
      session = Datarobot::AiApi::LearningSession.delete('5d322f2c5c142b15d2f826e7')
      assert_nil session
    end

    it "can get learning session deployment data", vcr: true do
      session = Datarobot::AiApi::LearningSession.find('5d41e055d8c81f0587732a93')
      deployment = session.deployment
      assert deployment
      assert deployment.is_a? Datarobot::AiApi::Deployment
      assert_equal deployment.target, 'score1'
    end

    it "can get learning session features", vcr: true do
      session = Datarobot::AiApi::LearningSession.find('5d41e055d8c81f0587732a93')
      features = session.features
      assert features
      assert features.is_a? Array
      assert_equal features.length, 12
    end

    it "can get learning session evaluation data", vcr: true do
      session = Datarobot::AiApi::LearningSession.find('5d76980cf2ff5200587ce3da')
      evaluation = session.evaluation
      assert evaluation
      assert_equal evaluation.summary, "Because 6.6% of the variability in the values of score1 are explained, fit accuracy for the current top performing model is ranked as weak."
    end
  end
end
