require 'test_helper'

describe "Datarobot::AiApi::Output" do
  before do
    @key = "testingKey"
  end

  it "is sane" do
    Datarobot::AiApi::Output.new
    # if we make it to here, nothing has exploded
    assert true
  end

  describe "when authorized" do
    before do
      Datarobot::AiApi.configure!(api_key: @key)
    end

    it "can list outputs", vcr: true do
      ai = Datarobot::AiApi::AI.find('5d5c6f7c42eabf0cb166f2c6')
      outputs = ai.outputs
      assert outputs.is_a? Datarobot::AiApi::Page
      assert_equal outputs.length, 1
      assert_includes(outputs.map(&:name), "test")
    end

    it "can create outputs", vcr: true do
      output = Datarobot::AiApi::Output.create(ai_id: '5d5c6f7c42eabf0cb166f2c6', output_name: 'test', learning_session_id: '5d420b75d8c81f05e0732a3d')
      assert output.is_a? Datarobot::AiApi::Output
      assert_equal output.name, "test"
    end

    it "can find named outputs", vcr: true do
      ai = Datarobot::AiApi::AI.find('5d5c6f7c42eabf0cb166f2c6')
      output = ai.find_output('test')
      assert output.is_a? Datarobot::AiApi::Output
      assert_equal output.name, "test"
    end

    it "can get features of an output", vcr: true do
      ai = Datarobot::AiApi::AI.find('5d5c6f7c42eabf0cb166f2c6')
      output = ai.find_output('test')
      features = output.features
      assert_includes features, {"type"=>"Categorical", "name"=>"league"}
    end

    it "can get the evaluation of an output", vcr: true do
      ai = Datarobot::AiApi::AI.find('5d76962ab153720056bb5783')
      output = ai.find_output('score1 output')
      evaluation = output.evaluation
      assert_equal evaluation.summary, "Because 6.6% of the variability in the values of score1 are explained, fit accuracy for the current top performing model is ranked as weak."
    end
  end
end
