require 'test_helper'

shared_examples_for 'a paginated resource' do
  describe "#next_page" do
    it "can go to the next page", vcr: true do
      raise "Set @klass in a before block to use pagination tests" unless @klass
      page = @klass.all(limit: 1, offset: 0)
      next_page = page.next_page
      assert next_page.is_a? Datarobot::AiApi::Page
      assert_equal next_page.items.length, 1
      assert_equal next_page.size, 1
    end
    it "returns the same page if there is no next page", vcr: true do
      # puts self.inspect
      raise "Set @klass in a before block to use pagination tests" unless @klass
      page = @klass.all(limit: 100, offset: 0)
      assert_nil page.links["next"]

      next_page = page.next_page
      assert_equal page, next_page
    end
  end
  describe "#previous_page" do
    it "can go to the previous page", vcr: true do
      raise "Set @klass in a before block to use pagination tests" unless @klass
      page_0 = @klass.all(limit: 1, offset: 0)
      assert_equal page_0.items.length, 1
      assert_equal page_0.size, 1

      page_1 = page_0.next_page
      page_2 = page_1.next_page

      assert page_0.is_a? Datarobot::AiApi::Page
      assert page_1.is_a? Datarobot::AiApi::Page
      assert page_2.is_a? Datarobot::AiApi::Page

      assert_equal page_1.map(&:id), page_2.previous_page.map(&:id)
    end

    it "returns the same page if there is no previous page", vcr: true do
      raise "Set @klass in a before block to use pagination tests" unless @klass
      page = @klass.all(limit: 1, offset: 0)

      assert_nil page.links['previous']

      prev_page = page.previous_page
      assert_equal page.map(&:id), prev_page.map(&:id)
    end
  end
end