require 'test_helper'
require_relative "test_refreshable.rb"

describe "Datarobot::AiApi::Task" do
  before do
    @key = "testingKey"
  end

  it "is sane" do
    Datarobot::AiApi::Task.new
    # if we make it to here, nothing has exploded
    assert true
  end

  describe "when authorized" do
    before do
      Datarobot::AiApi.configure!(api_key: @key)
      @klass = Datarobot::AiApi::Task
      @id = '5d0efc9e-b77e-40e4-bd7e-1d162b53155c'
    end

    it_behaves_like "a refreshable resource"

    it "check the status of a task", vcr: true do
      task = Datarobot::AiApi::Task.find('5d0efc9e-b77e-40e4-bd7e-1d162b53155c')
      assert task.is_a? Datarobot::AiApi::Task
      assert_equal task.status, "COMPLETED"
    end

    it "can stop a task", vcr: true do
      task = Datarobot::AiApi::Task.stop('5d0efc9e-b77e-40e4-bd7e-1d162b53155c')
      assert_nil task
    end

    it "handles when Task ID is nil" do
      assert_raises Datarobot::AiApi::NotFoundError do
        task = Datarobot::AiApi::Task.find(nil)
      end
    end

    it "can wait until completed", vcr: true do
      resp_data = Datarobot::AiApi.upload_to_endpoint('/aiapi/datasets/fileImports', './test/data/test.csv')
      task = Datarobot::AiApi::Task.new(resp_data)

      dataset = task.wait_until_complete

      task = Datarobot::AiApi::Task.find(task.id)
      assert task.status == "COMPLETED"
      assert dataset.is_a? Datarobot::AiApi::Dataset
    end
  end
end

